@@ -3,9 +3,9 @@ package Sah::Schema::hexstr;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-03'; # DATE
+our $DATE = '2023-10-23'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 our $schema = [str => {
     summary => 'String of bytes in hexadecimal notation, e.g. "ab99" or "CAFE"',
@@ -45,7 +45,7 @@ Sah::Schema::hexstr - String of bytes in hexadecimal notation, e.g. "ab99" or "C
 
 =head1 VERSION
 
-This document describes version 0.015 of Sah::Schema::hexstr (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
+This document describes version 0.016 of Sah::Schema::hexstr (from Perl distribution Sah-Schemas-Str), released on 2023-10-23.
 
 =head1 SYNOPSIS
 
@@ -83,11 +83,11 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "";
+ $data = "a0ff12345678";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "a0fg";
+ $data = "a0f";
  my $errmsg = $validator->($data); # => "Must match regex pattern qr(\\A(?:[0-9A-Fa-f]{2})*\\z)"
 
 Often a schema has coercion rule or default value rules, so after validation the
@@ -98,12 +98,12 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "";
- my $res = $validator->($data); # => ["",""]
+ $data = "a0ff12345678";
+ my $res = $validator->($data); # => ["","a0ff12345678"]
  
  # a sample invalid data
- $data = "a0fg";
- my $res = $validator->($data); # => ["Must match regex pattern qr(\\A(?:[0-9A-Fa-f]{2})*\\z)","a0fg"]
+ $data = "a0f";
+ my $res = $validator->($data); # => ["Must match regex pattern qr(\\A(?:[0-9A-Fa-f]{2})*\\z)","a0f"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
