@@ -3,9 +3,9 @@ package Sah::Schema::latin_uppercase_letter;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-09-03'; # DATE
+our $DATE = '2023-10-23'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 our $schema = [str => {
     summary => 'A single latin uppercase letter, i.e. A-Z',
@@ -39,7 +39,7 @@ Sah::Schema::latin_uppercase_letter - A single latin uppercase letter, i.e. A-Z
 
 =head1 VERSION
 
-This document describes version 0.015 of Sah::Schema::latin_uppercase_letter (from Perl distribution Sah-Schemas-Str), released on 2023-09-03.
+This document describes version 0.016 of Sah::Schema::latin_uppercase_letter (from Perl distribution Sah-Schemas-Str), released on 2023-10-23.
 
 =head1 SYNOPSIS
 
@@ -77,8 +77,8 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = ";";
- my $errmsg = $validator->($data); # => "Must match regex pattern qr(\\A[A-Z]\\z)"
+ $data = "";
+ my $errmsg = $validator->($data); # => "Length must be 1"
 
 Often a schema has coercion rule or default value rules, so after validation the
 validated value will be different from the original. To return the validated
@@ -92,8 +92,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # => ["","A"]
  
  # a sample invalid data
- $data = ";";
- my $res = $validator->($data); # => ["Must match regex pattern qr(\\A[A-Z]\\z)",";"]
+ $data = "";
+ my $res = $validator->($data); # => ["Length must be 1",""]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -198,6 +198,8 @@ Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Str>.
 
 L<Sah::Schema::latin_uppercase_letter>
 
+L<Sah::Schema::lowercase_str>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
